@@ -333,6 +333,13 @@ where
         self.method
     }
 
+    /**
+    overrides the http method for this conn
+     */
+    pub fn set_method(&mut self, method: Method) {
+        self.method = method;
+    }
+
     /**
     returns the http version for this conn.
     */
@@ -528,8 +535,10 @@ where
             return;
         }
 
-        if let Some(len) = self.body_len() {
-            self.response_headers.apply(ContentLength::new(len));
+        if self.response_headers.get(CONTENT_LENGTH).is_none() {
+            if let Some(len) = self.body_len() {
+                self.response_headers.apply(ContentLength::new(len));
+            }
         }
 
         if self.response_headers.get(CONTENT_LENGTH).is_none() {
